@@ -21,9 +21,12 @@ use Cache::FileCache;
 use Cache::Cache;
 use Cwd;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 our $TGZ     = "tar.tgz";
 
+  # These troublemakers are ignored when listed as a dependency
+our %BLACKLISTED = map { $_ => 1 } qw(perl);
+
 ###########################################
 sub new {
 ###########################################
@@ -130,7 +133,7 @@ sub lookup {
         $result->{dependents}->{$mname} = [];
 
         for(keys %$deps) {
-
+            DEBUG "Adding dependency $_";
             push @{$result->{dependents}->{$mname}}, $_;
 
             $unresolved{$_} = 1 unless exists $resolved{$_};
@@ -213,6 +216,8 @@ sub lookup_single {
         DEBUG "Found dependent_versions of $mname: ", Dumper($deps);
     };
 
+    delete $deps->{$_} for keys %BLACKLISTED;
+
     chdir $cwd or LOGDIE "Cannot chdir to $cwd";
 
     return CPAN::Unwind::Response->new(
